<?php
/*
 * Plugin Name: MihanWP IRR Schema Fix
 * Plugin URI: https://mihanwp.com/invalid-iso-4217-currency-code/
 * Description: A plugin to modify the Open Graph meta tags for WooCommerce product pages to use IRR currency. The feature is enabled by default and can be disabled in the WooCommerce settings.
 * Version: 1.0.0
 * Author: Ertano
 * Author URI: https://ertano.com
 * Text Domain: mihanwp-irr-schema-fix
 * Domain Path: /languages
 */

// Load the plugin's text domain
function mihanwp_irr_schema_fix_load_textdomain() {
    load_plugin_textdomain( 'mihanwp-irr-schema-fix', false, basename( dirname( __FILE__ ) ) . '/languages' );
}
add_action( 'plugins_loaded', 'mihanwp_irr_schema_fix_load_textdomain' );

// Add settings to WooCommerce
function mihanwp_irr_add_settings( $settings ) {
    $settings[] = array(
        'title' => __( 'MihanWP IRR Schema Fix', 'mihanwp-irr-schema-fix' ),
        'type'  => 'title',
        'desc'  => sprintf( __( 'Settings for MihanWP IRR Schema Fix. More information <a href="%s" target="_blank">here</a>.', 'mihanwp-irr-schema-fix' ), 'https://mihanwp.com/invalid-iso-4217-currency-code/' ),
        'id'    => 'mihanwp_irr_schema_fix_options',
    );

    $settings[] = array(
        'title'   => __( 'Enable IRR Schema Fix', 'mihanwp-irr-schema-fix' ),
        'desc'    => __( 'Check this box to enable the IRR Schema Fix.', 'mihanwp-irr-schema-fix' ),
        'id'      => 'mihanwp_irr_schema_fix_enable',
        'default' => 'yes',
        'type'    => 'checkbox',
    );

    $settings[] = array( 'type' => 'sectionend', 'id' => 'mihanwp_irr_schema_fix_options' );

    return $settings;
}
add_filter( 'woocommerce_get_settings_products', 'mihanwp_irr_add_settings', 10, 1 );

// Custom currency function
function mihanwp_irr_custom_woocommerce_currency( $currency ) {
    if ( 'yes' === get_option( 'mihanwp_irr_schema_fix_enable', 'yes' ) ) {
        $backtrace = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, 5);

        foreach ($backtrace as $trace) {
            if (isset($trace['class']) && strpos($trace['class'], 'RankMath\WooCommerce\Opengraph') !== false) {
                return 'IRR';
            }
        }
    }

    return $currency;
}
add_filter( 'woocommerce_currency', 'mihanwp_irr_custom_woocommerce_currency', 10, 1 );
